@@ -2,12 +2,13 @@ package Mojo::Util::Collection;
 use Mojo::Base -base;
 
 use Exporter 'import';
+use Mojo::Util::Model;
 
 our @EXPORT_OK = qw(
     collect
 );
 
-our $VERSION = '0.0.14';
+our $VERSION = '0.0.15';
 
 use List::Util;
 use Scalar::Util qw(blessed);
@@ -314,6 +315,23 @@ sub indexOf {
     return $index;
 }
 
+=head2 intersect
+
+    Return a new collection containing only items that exist in both collections
+
+    Returns:
+    C<Collection> of C<Model> objects
+
+=cut
+
+sub intersect {
+    my ($self, $other_collection) = @_;
+
+    return $self->search({
+        $self->model->pk => $other_collection->lists($other_collection->model->pk),
+    });
+}
+
 =head2 last
 
     Get last object
@@ -376,6 +394,24 @@ sub min {
     return List::Util::min(@$values);
 }
 
+=head2 missing
+
+    Return a new collection containing only items that exist in this collection
+    but not in the other collection
+
+    Returns:
+    C<Collection> of C<Model> objects
+
+=cut
+
+sub missing {
+    my ($self, $other_collection) = @_;
+
+    return $self->exclude({
+        $self->model->pk => $other_collection->lists($other_collection->model->pk),
+    });
+}
+
 =head2 newObject
 
     Instantiate new object
